@@ -17,15 +17,16 @@ The events described here are *not* trigged by Grok itself. They are
 conveniently provided to be used in your own application.
 
 """
-from grok import interfaces
+import grok.interfaces
+import grokcore.site.interfaces
 from zope.interface import implements
 
 
 class ApplicationInitializedEvent(object):
     """A Grok Application has been created and is now ready to be used.
     """
-    implements(interfaces.IApplicationInitializedEvent)
+    implements(grok.interfaces.IApplicationInitializedEvent)
 
     def __init__(self, app):
-        assert interfaces.IApplication.providedBy(app)
+        assert grokcore.site.interfaces.IApplication.providedBy(app)
         self.object = app
