@@ -25,28 +25,38 @@ import grokcore.component.interfaces
 import grokcore.formlib.interfaces
 import grokcore.json.interfaces
 import grokcore.security.interfaces
+import grokcore.rest.interfaces
 import grokcore.site.interfaces
 import grokcore.view.interfaces
 import grokcore.viewlet.interfaces
+import grokcore.xmlrpc.interfaces
+import grokcore.traverser.interfaces
 
 from grokcore.component.interfaces import IContext
 from grokcore.component.interfaces import IGrokErrors
 
 
+from grokcore.rest.interfaces import IREST, IRESTSkinType, IRESTLayer
+
 class IGrokBaseClasses(grokcore.annotation.interfaces.IBaseClasses,
                        grokcore.component.interfaces.IBaseClasses,
                        grokcore.security.interfaces.IBaseClasses,
+                       grokcore.rest.interfaces.IBaseClasses,
                        grokcore.site.interfaces.IBaseClasses,
                        grokcore.view.interfaces.IBaseClasses,
-                       grokcore.json.interfaces.IBaseClasses):
-    Model = interface.Attribute("Base class for persistent content objects "
-                                "(models).")
+                       grokcore.json.interfaces.IBaseClasses,
+                       grokcore.traverser.interfaces.IBaseClasses,
+                       grokcore.xmlrpc.interfaces.IBaseClasses):
+    Model = interface.Attribute(
+        "Base class for persistent content objects (models).")
     Container = interface.Attribute("Base class for containers.")
     OrderedContainer = interface.Attribute("Base class for ordered containers.")
     Application = interface.Attribute("Base class for applications.")
-    XMLRPC = interface.Attribute("Base class for XML-RPC methods.")
-    REST = interface.Attribute("Base class for REST views.")
-    Traverser = interface.Attribute("Base class for custom traversers.")
+    View = interface.Attribute("Base class views.")
+    ExceptionView = interface.Attribute("Base class for excetion views.")
+    NotFoundView = interface.Attribute("Base class notfound exception views.")
+    UnauthorizedView = interface.Attribute(
+        "Base class unauthorized exception views.")
     Indexes = interface.Attribute("Base class for catalog index definitions.")
     Role = interface.Attribute("Base class for roles.")
 
@@ -147,9 +157,6 @@ class IGrokAPI(grokcore.formlib.interfaces.IGrokcoreFormlibAPI,
     def getSite():
         """Get the current site."""
 
-    def getApplication():
-        """Return the nearest enclosing `grok.Application`."""
-
     IRESTSkinType = interface.Attribute('The REST skin type')
 
 
@@ -170,24 +177,6 @@ class IGrokForm(grokcore.formlib.interfaces.IGrokForm, IGrokView):
     """All Grok forms provides this interface."""
 
 
-class IREST(interface.Interface):
-    context = interface.Attribute("Object that the REST handler presents.")
-
-    request = interface.Attribute("Request that REST handler was looked"
-                                  "up with.")
-
-    body = interface.Attribute(
-        """The text of the request body.""")
-
-
-class IApplication(interface.Interface):
-    """Marker-interface for grok application factories.
-
-    Used to register applications as utilities to look them up and
-    provide a list of grokked applications.
-    """
-
-
 class IIndexDefinition(interface.Interface):
     """Define an index for grok.Indexes.
     """
@@ -200,18 +189,6 @@ class IIndexDefinition(interface.Interface):
         """
 
 
-class IRESTLayer(IHTTPRequest):
-    """REST-specific Request functionality.
-
-    Base Interfaces for defining REST-layers.
-    """
-
-
-class IRESTSkinType(IInterface):
-    """Skin type for REST requests.
-    """
-
-
 class IContainer(IContext, IContainerBase):
     """A Grok container.
     """
